package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.DHParameter;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.crypto.params.DHPublicKeyParameters;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import javax.crypto.interfaces.DHPublicKey;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.DHPublicKeySpec;

public class JCEDHPublicKey implements DHPublicKey {
   static final long serialVersionUID = -216691575254424324L;
   private BigInteger y;
   private DHParameterSpec dhSpec;

   JCEDHPublicKey(DHPublicKeySpec spec) {
      JCEDHPublicKey var10000 = this;
      super();
      this.y = spec.getY();
      BigInteger var2 = spec.getP();
      var10000.dhSpec = new DHParameterSpec(var2, spec.getG());
   }

   JCEDHPublicKey(DHPublicKey key) {
      this.y = key.getY();
      this.dhSpec = key.getParams();
   }

   JCEDHPublicKey(DHPublicKeyParameters params) {
      JCEDHPublicKey var10000 = this;
      super();
      this.y = params.getY();
      BigInteger var10003 = params.getParameters().getP();
      BigInteger var2 = params.getParameters().getG();
      var10000.dhSpec = new DHParameterSpec(var10003, var2, params.getParameters().getL());
   }

   JCEDHPublicKey(BigInteger y, DHParameterSpec dhSpec) {
      this.y = y;
      this.dhSpec = dhSpec;
   }

   JCEDHPublicKey(SubjectPublicKeyInfo info) {
      SubjectPublicKeyInfo var10001 = info;
      super();
      DHParameter var2;
      var2 = new DHParameter.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());

      DERInteger var7;
      try {
         var7 = (DERInteger)var10001.getPublicKey();
      } catch (IOException var3) {
         throw new IllegalArgumentException("invalid info structure in DH public key");
      }

      this.y = var7.getValue();
      JCEDHPublicKey var10000;
      BigInteger info1;
      if (var2.getL() != null) {
         var10000 = this;
         BigInteger var4 = var2.getP();
         info1 = var2.getG();
         var10000.dhSpec = new DHParameterSpec(var4, info1, var2.getL().intValue());
      } else {
         var10000 = this;
         DHParameterSpec var5;
         DHParameterSpec var8 = var5 = new DHParameterSpec;
         info1 = var2.getP();
         var8.<init>(info1, var2.getG());
         var10000.dhSpec = var5;
      }

   }

   private void readObject(ObjectInputStream in) {
      JCEDHPublicKey var10000 = this;
      this.y = (BigInteger)in.readObject();
      ObjectInputStream var10003 = in;
      BigInteger var3 = (BigInteger)in.readObject();
      BigInteger in1 = (BigInteger)in.readObject();
      int var2 = var10003.readInt();
      var10000.dhSpec = new DHParameterSpec(var3, in1, var2);
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.getY());
      out.writeObject(this.dhSpec.getP());
      out.writeObject(this.dhSpec.getG());
      out.writeInt(this.dhSpec.getL());
   }

   public String getAlgorithm() {
      return "DH";
   }

   public String getFormat() {
      return "X.509";
   }

   public byte[] getEncoded() {
      DERObjectIdentifier var10004 = X9ObjectIdentifiers.dhpublicnumber;
      BigInteger var10007 = this.dhSpec.getP();
      BigInteger var1 = this.dhSpec.getG();
      return (new SubjectPublicKeyInfo(new AlgorithmIdentifier(var10004, (new DHParameter(var10007, var1, this.dhSpec.getL())).getDERObject()), new DERInteger(this.y))).getDEREncoded();
   }

   public DHParameterSpec getParams() {
      return this.dhSpec;
   }

   public BigInteger getY() {
      return this.y;
   }
}
